@@ -23,7 +23,7 @@ def create_root_type(fields):
 
     return strawberry.type(cls)
 
-def create_validation_error_type(type_: StrawberryField):
+def create_validation_error_type(prefix: str, type_: StrawberryField):
     @classmethod
     def from_validation_error(cls, validation_error: pydantic.ValidationError):
         errors = validation_error.errors()
@@ -39,6 +39,6 @@ def create_validation_error_type(type_: StrawberryField):
 
         return cls(errors=type_(**payload))
 
-    cls = make_dataclass(f"ValidationError", [("errors", type_)])
+    cls = make_dataclass(f"{prefix}ValidationError", [("errors", type_)])
     cls.from_validation_error = from_validation_error
     return strawberry.type(cls)
